@@ -34,6 +34,7 @@ pub struct LazyCsvReader<'a> {
     schema: Option<SchemaRef>,
     schema_overwrite: Option<&'a Schema>,
     low_memory: bool,
+    comment_char: Option<u8>,
 }
 
 #[cfg(feature = "csv-file")]
@@ -50,6 +51,7 @@ impl<'a> LazyCsvReader<'a> {
             schema: None,
             schema_overwrite: None,
             low_memory: false,
+            comment_char: None,
         }
     }
 
@@ -97,6 +99,12 @@ impl<'a> LazyCsvReader<'a> {
         self
     }
 
+    /// Set the comment character. Lines starting with this character will be ignored.
+    pub fn with_comment_char(mut self, comment_char: Option<u8>) -> Self {
+        self.comment_char = comment_char;
+        self
+    }
+
     /// Cache the DataFrame after reading.
     pub fn with_cache(mut self, cache: bool) -> Self {
         self.cache = cache;
@@ -121,6 +129,7 @@ impl<'a> LazyCsvReader<'a> {
             self.schema,
             self.schema_overwrite,
             self.low_memory,
+            self.comment_char,
         )
         .build()
         .into();
@@ -2179,7 +2188,7 @@ mod test {
             .collect()?;
 
         assert_eq!(
-            Vec::from(out.column("collected")?.explode()?.i32()?),
+            Vec::from(out.column("vals")?.explode()?.i32()?),
             [1, 5, 11, 3, 12, 20]
                 .iter()
                 .copied()
@@ -2302,4 +2311,26 @@ mod test {
         );
         Ok(())
     }
+
+    #[test]
+    fn test_fill_forward() -> Result<()> {
+        let df = df![
+            "a" => ["a", "b", "a"],
+            "b" => [Some(1), None, None]
+        ]?;
+
+        let out = df
+            .lazy()
+            .select(vec![col("b").forward_fill().over(vec![col("a")])])
+            .collect()?;
+        let agg = out.column("b")?.list()?;
+
+        let a: Series = agg.get(0).unwrap();
+        assert!(a.series_equal(&Series::new("b", &[1, 1])));
+        let a: Series = agg.get(2).unwrap();
+        assert!(a.series_equal(&Series::new("b", &[1, 1])));
+        let a: Series = agg.get(1).unwrap();
+        assert_eq!(a.null_count(), 1);
+        Ok(())
+    }
 }
