@@ -121,16 +121,9 @@ impl DefaultPlanner {
             CsvScan {
                 path,
                 schema,
-                has_header,
-                delimiter,
-                ignore_errors,
-                skip_rows,
-                stop_after_n_rows,
-                with_columns,
+                options,
                 predicate,
                 aggregate,
-                cache,
-                low_memory,
             } => {
                 let predicate = predicate
                     .map(|pred| self.create_physical_expr(pred, Context::Default, expr_arena))
@@ -139,16 +132,9 @@ impl DefaultPlanner {
                 Ok(Box::new(CsvExec {
                     path,
                     schema,
-                    has_header,
-                    delimiter,
-                    ignore_errors,
-                    skip_rows,
-                    stop_after_n_rows,
-                    with_columns,
+                    options,
                     predicate,
                     aggregate,
-                    cache,
-                    low_memory,
                 }))
             }
             #[cfg(feature = "parquet")]
@@ -401,6 +387,8 @@ impl DefaultPlanner {
                 // TODO! Order by
                 let group_by =
                     self.create_physical_expressions(&partition_by, Context::Default, expr_arena)?;
+                let phys_function =
+                    self.create_physical_expr(function, Context::Aggregation, expr_arena)?;
                 let mut out_name = None;
                 let mut apply_columns = aexpr_to_root_names(function, expr_arena);
                 if apply_columns.len() > 1 {
@@ -421,6 +409,7 @@ impl DefaultPlanner {
                     apply_column,
                     out_name,
                     function,
+                    phys_function,
                 }))
             }
             Literal(value) => Ok(Arc::new(LiteralExpr::new(
